#include <bits/stdc++.h>

using namespace std;

typedef long long ll;

struct SegmentTree1 {
    vector<ll> tree;
    vector<ll> add;
    vector<bool> is_add;
    ll n;

    explicit SegmentTree1(ll n) : n(n) {
        tree.assign(4 * n, 0);
        add.assign(4 * n, 0);
        is_add.assign(4 * n, false);

        build(0, 0, n);
    }

    void build(ll v, ll l, ll r) {
        if (l == r - 1) {
            tree[v] = l;
            return;
        }
        ll m = (l + r) / 2;
        build(v * 2 + 1, l, m);
        build(v * 2 + 2, m, r);
        tree[v] = max(tree[2 * v + 1], tree[2 * v + 2]);
    }

    void push(ll v) {
        if (is_add[v]) {
            tree[2 * v + 1] += add[v];
            tree[2 * v + 2] += add[v];
            add[2 * v + 1] += add[v];
            add[2 * v + 2] += add[v];
            is_add[2 * v + 1] = true;
            is_add[2 * v + 2] = true;
            add[v] = 0;
            is_add[v] = false;
        }
    }

    void add_val(ll v, ll l, ll r, ll ql, ll qr, ll val) {
        if (qr <= l || r <= ql) {
            return;
        }
        if (ql <= l && r <= qr) {
            tree[v] += val;
            add[v] += val;
            is_add[v] = true;
            return;
        }
        push(v);
        ll m = (l + r) / 2;
        add_val(2 * v + 1, l, m, ql, qr, val);
        add_val(2 * v + 2, m, r, ql, qr, val);
        tree[v] = max(tree[2 * v + 1], tree[2 * v + 2]);
    }

    void add_val(ll ql, ll qr, ll val) {
        add_val(0, 0, n, ql, qr, val);
    }

    ll get(ll v, ll l, ll r, ll x) {
        if (l == r - 1) {
            return l;
        }
        push(v);
        ll m = (l + r) / 2;
        if (tree[2 * v + 1] >= x) {
            return get(2 * v + 1, l, m, x);
        } else {
            return get(2 * v + 2, m, r, x);
        }
    }

    ll get(ll x) {
        return get(0, 0, n, x);
    }
};

struct SegmentTree2 {
    vector<ll> h;
    vector<ll> tree;
    vector<ll> set;
    vector<bool> is_set;
    ll n;

    explicit SegmentTree2(const vector<ll> &h) : h(h) {
        n = static_cast<ll>(h.size());
        tree.assign(4 * n, 0);
        set.assign(4 * n, 0);
        is_set.assign(4 * n, false);

        build(0, 0, n);
    }

    void build(ll v, ll l, ll r) {
        if (l == r - 1) {
            tree[v] = h[l];
            return;
        }
        ll m = (l + r) / 2;
        build(v * 2 + 1, l, m);
        build(v * 2 + 2, m, r);
        tree[v] = tree[2 * v + 1] + tree[2 * v + 2];
    }

    void push(ll v, ll l, ll r) {
        ll m = (l + r) / 2;
        if (is_set[v]) {
            tree[2 * v + 1] = set[v] * (m - l);
            tree[2 * v + 2] = set[v] * (r - m);
            set[2 * v + 1] = set[v];
            set[2 * v + 2] = set[v];
            is_set[2 * v + 1] = true;
            is_set[2 * v + 2] = true;
            set[v] = 0;
            is_set[v] = false;
        }
    }

    void update(ll v, ll l, ll r, ll ql, ll qr, ll val) {
        if (qr <= l || r <= ql) {
            return;
        }
        if (ql <= l && r <= qr) {
            tree[v] = val * (r - l);
            set[v] = val;
            is_set[v] = true;
            return;
        }
        push(v, l, r);
        ll m = (l + r) / 2;
        update(2 * v + 1, l, m, ql, qr, val);
        update(2 * v + 2, m, r, ql, qr, val);
        tree[v] = tree[2 * v + 1] + tree[2 * v + 2];
    }

    void update(ll ql, ll qr, ll val) {
        return update(0, 0, n, ql, qr, val);
    }

    ll get(ll v, ll l, ll r, ll ql, ll qr) {
        if (qr <= l || r <= ql) {
            return 0;
        }
        if (ql <= l && r <= qr) {
            return tree[v];
        }
        push(v, l, r);
        ll m = (l + r) / 2;
        ll x = get(2 * v + 1, l, m, ql, qr);
        ll y = get(2 * v + 2, m, r, ql, qr);
        return x + y;
    }

    ll get(ll ql, ll qr) {
        return get(0, 0, n, ql, qr);
    }

    void print(ll v, ll l, ll r) {
        if (l == r - 1) {
            cout << tree[v] << ' ';
            return;
        }
        push(v, l, r);
        ll m = (l + r) / 2;
        print(2 * v + 1, l, m);
        print(2 * v + 2, m, r);
    }

    void print() {
        print(0, 0, n);
    }
};

struct SparseTable {
    vector<ll> a;
    vector<vector<ll> > mx;
    vector<ll> lg;

    explicit SparseTable(const vector<ll> &a): a(a) {
        ll n = static_cast<ll>(a.size());
        ll k = 0;
        while ((1 << k) <= n) {
            k++;
        }
        mx.assign(k, vector<ll>(n));
        for (ll i = 0; i < n; i++) {
            mx[0][i] = i;
        }
        for (ll i = 1; i < k; i++) {
            for (ll j = 0; j + (1 << i) <= n; j++) {
                if (a[mx[i - 1][j]] > a[mx[i - 1][j + (1 << (i - 1))]]) {
                    mx[i][j] = mx[i - 1][j];
                } else {
                    mx[i][j] = mx[i - 1][j + (1 << (i - 1))];
                }
            }
        }
        lg.assign(n + 1, 0);
        lg[1] = 0;
        for (ll i = 2; i <= n; i++) {
            lg[i] = lg[i / 2] + 1;
        }
    }

    ll get(ll l, ll r) {
        ll x = lg[r - l];
        if (a[mx[x][l]] > a[mx[x][r - (1 << x)]]) {
            return mx[x][l];
        } else {
            return mx[x][r - (1 << x)];
        }
    }
};

int main() {
#ifdef DEBUG_Q
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
#endif
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);

    ll n;
    cin >> n;
    vector<ll> h(n);
    for (ll i = 0; i < n; i++) {
        cin >> h[i];
    }
    SegmentTree1 tree1(n + 1);
    SparseTable st(h);
    SegmentTree2 tree2(h);

    vector<ll> p(n + 1);
    for (ll i = 1; i <= n; i++) {
        p[i] = p[i - 1] + h[i - 1];
    }

    for (ll e = 0; e < n - 1; e++) {
        ll k;
        cin >> k;
        k--;
        ll p1 = tree1.get(k);
        ll p2 = tree1.get(k + 1);
        ll p3 = tree1.get(k + 2);
        ll mx1 = st.get(p1, p2);
        ll mx2 = st.get(p2, p3);
        if (h[mx1] > h[mx2]) {
            ll l = p1, r = p2;
            while (r - l > 1) {
                ll m = (l + r) / 2;
                if (h[st.get(m, p2)] >= h[mx2]) {
                    l = m;
                } else {
                    r = m;
                }
            }
            tree2.update(l + 1, mx2 + 1, h[mx2]);
        } else {
            ll l = p2 - 1, r = p3 - 1;
            while (r - l > 1) {
                ll m = (l + r) / 2;
                if (h[st.get(p2, m + 1)] >= h[mx1]) {
                    r = m;
                } else {
                    l = m;
                }
            }
            tree2.update(mx1, r, h[mx1]);
        }
        ll ans = tree2.get(p1, p3);
        ans -= p[p3] - p[p1];
        cout << ans << '\n';
        tree1.add_val(p2, n + 1, -1);
    }
}
